==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/th_TH.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "ข้อมูลผู้ติดต่อ",
    "Address book name" : "สมุดชื่อที่อยู่",
    "Import" : "นำเข้า",
    "The selected image is too big (max 1MB)" : "รูปภาพที่เลือกมีขนาดใหญ่เกินไป (ขนาดไม่ควรเกิน 1 เมกะไบต์)",
    "No contacts in here" : "ไม่มีรายชื่อในที่นี่",
    "Name" : "ชื่อ",
    "Organization" : "หน่วยงาน",
    "Title" : "ชื่อเรื่อง",
    "Add field ..." : "เพิ่มช่อง ...",
    "+ New contact" : "เพิ่มรายชื่อใหม่",
    "No search result for {query}" : "ไม่พบผลลัพธ์การค้นหาสำหรับ {query}",
    "_%n contact_::_%n contacts_" : ["%n รายชื่อผู้ติดต่อ"],
    "Post office box" : "กล่องจดหมาย",
    "Postal code" : "รหัสไปรษณีย์",
    "City" : "เมือง",
    "State or province" : "รัฐหรือจังหวัด",
    "Country" : "ประเทศ",
    "Address" : "ที่อยู่",
    "(new group)" : "(กลุ่มใหม่)",
    "Last name" : "นามสกุลจริง",
    "First name" : "ชื่อจริง",
    "Additional names" : "ชื่ออื่นๆ",
    "Prefix" : "คำนำหน้า",
    "Suffix" : "คำต่อท้าย",
    "All contacts" : "รายชื่อทั้งหมด",
    "Not grouped" : "ไม่ถูกจัดกลุ่ม",
    "New contact" : "รายชื่อผุ้ติดต่อใหม่",
    "{addressbook} shared by {owner}" : "{addressbook} ถูกแชร์โดย {owner}",
    "No contacts in file. Only VCard files are allowed." : "ไม่มีรายชื่อในไฟล์ เฉพาะไฟล์วีการ์ดจะได้รับอนุญาต",
    "Nickname" : "ชื่อเล่น",
    "Detailed name" : "รายละเอียดชื่อ",
    "Notes" : "บันทึกย่อ",
    "Website" : "เว็บไซต์",
    "Federated Cloud ID" : "ไอดีคลาวด์ในเครือ",
    "Home" : "บ้าน",
    "Work" : "ที่ทำงาน",
    "Other" : "อื่นๆ",
    "Groups" : "กลุ่ม",
    "Birthday" : "วันเกิด",
    "Anniversary" : "วันครบรอบ",
    "Date of death" : "วันที่สิ้นสุด",
    "Email" : "อีเมล",
    "Instant messaging" : "ส่งข้อความโต้ตอบแบบทันที",
    "Phone" : "โทรศัพท์",
    "Mobile" : "มือถือ",
    "Fax" : "โทรสาร",
    "Fax home" : "แฟกซ์ที่บ้าน",
    "Fax work" : "แฟกซ์ที่ทำงาน",
    "Pager" : "เพจเจอร์",
    "Voice" : "เสียงพูด",
    "Social network" : "เครือข่ายทางสังคม",
    "Settings" : "ตั้งค่า"
},
"nplurals=1; plural=0;");

==> owncloud-app-contacts-2%3A1.5.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/th_TH.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "ข้อมูลผู้ติดต่อ",
    "Copy Url to clipboard" : "ดลอก URL ไปยังคลิปบอร์ด",
    "Download" : "ดาวน์โหลด",
    "ShowURL" : "แสดง URL",
    "Share Addressbook" : "แชร์สมุดที่อยู่",
    "Delete Addressbook" : "ลบสมุดที่อยู่",
    "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
    "Delete" : "ลบ",
    "can edit" : "สามารถแก้ไข",
    "Address book name" : "สมุดชื่อที่อยู่",
    "Import" : "นำเข้า",
    "The selected image is too big (max 1MB)" : "รูปภาพที่เลือกมีขนาดใหญ่เกินไป (ขนาดไม่ควรเกิน 1 เมกะไบต์)",
    "No contacts in here" : "ไม่มีรายชื่อในที่นี่",
    "Name" : "ชื่อ",
    "Organization" : "หน่วยงาน",
    "Title" : "ชื่อเรื่อง",
    "Add field ..." : "เพิ่มช่อง ...",
    "No search result for {query}" : "ไม่พบผลลัพธ์การค้นหาสำหรับ {query}",
    "_%n contact_::_%n contacts_" : ["%n รายชื่อผู้ติดต่อ"],
    "Post office box" : "กล่องจดหมาย",
    "Postal code" : "รหัสไปรษณีย์",
    "City" : "เมือง",
    "State or province" : "รัฐหรือจังหวัด",
    "Country" : "ประเทศ",
    "Address" : "ที่อยู่",
    "(new group)" : "(กลุ่มใหม่)",
    "Last name" : "นามสกุลจริง",
    "First name" : "ชื่อจริง",
    "Additional names" : "ชื่ออื่นๆ",
    "Prefix" : "คำนำหน้า",
    "Suffix" : "คำต่อท้าย",
    "All contacts" : "รายชื่อทั้งหมด",
    "Not grouped" : "ไม่ถูกจัดกลุ่ม",
    "New contact" : "รายชื่อผุ้ติดต่อใหม่",
    "{addressbook} shared by {owner}" : "{addressbook} ถูกแชร์โดย {owner}",
    "Contact could not be created." : "ไม่สามารถสร้างรายชื่อผู้ติดต่อ",
    "No contacts in file. Only VCard files are allowed." : "ไม่มีรายชื่อในไฟล์ เฉพาะไฟล์วีการ์ดจะได้รับอนุญาต",
    "Only VCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "รองรับเฉพาะ VCard รุ่น 4.0 (RFC6350) หรือรุ่น 3.0 (RFC2426) ",
    "Nickname" : "ชื่อเล่น",
    "Detailed name" : "รายละเอียดชื่อ",
    "Notes" : "บันทึกย่อ",
    "Website" : "เว็บไซต์",
    "Federated Cloud ID" : "ไอดีคลาวด์ในเครือ",
    "Home" : "บ้าน",
    "Work" : "ที่ทำงาน",
    "Other" : "อื่นๆ",
    "Groups" : "กลุ่ม",
    "Birthday" : "วันเกิด",
    "Anniversary" : "วันครบรอบ",
    "Date of death" : "วันที่สิ้นสุด",
    "Email" : "อีเมล",
    "Instant messaging" : "ส่งข้อความโต้ตอบแบบทันที",
    "Phone" : "โทรศัพท์",
    "Mobile" : "มือถือ",
    "Fax" : "โทรสาร",
    "Fax home" : "แฟกซ์ที่บ้าน",
    "Fax work" : "แฟกซ์ที่ทำงาน",
    "Pager" : "เพจเจอร์",
    "Voice" : "เสียงพูด",
    "Social network" : "เครือข่ายทางสังคม",
    "Settings" : "ตั้งค่า"
},
"nplurals=1; plural=0;");
